@@ -7,8 +7,7 @@
 //! # Note:
 //!
 //! This crate requires a win32 event loop to be running on the thread, otherwise the notification will close immediately,
-//! it is recommended to use it with other win32 event loop crates like [tao](https://docs.rs/tao) or
-//! [winit](https://docs.rs/winit) or just roll your own win32 event loop.
+//! it is recommended to use it with other win32 event loop crates like [winit](https://docs.rs/winit) or just use your own win32 event loop.
 //!
 //! # Examples
 //!
@@ -16,6 +15,7 @@
 //!
 //! ```no_run
 //! # use win7_notifications::*;
+//! # let icon = &[];
 //! Notification::new()
 //!     .appname("App name")
 //!     .summary("Critical Error")
@@ -29,6 +29,7 @@
 //!
 //! ```no_run
 //! # use win7_notifications::*;
+//! # let icon = &[];
 //! Notification::new()
 //!     .appname("App name")
 //!     .summary("Critical Error")
@@ -39,6 +40,7 @@
 //! ```
 //!
 
+mod definitions;
 mod notification;
 mod timeout;
 mod util;
